<!-- markdownlint-disable MD041 -->

- uv-workon version:
- Python version:
- Operating System:

### Description

Describe what you were trying to get done. Tell us what happened, what went
wrong, and what you expected to happen.

### What I Did

```bash
Paste the command(s) you ran and the output.
If there was a crash, please include the traceback here.
```
